@@ -1,23 +1,14 @@
 from __future__ import absolute_import, print_function, division
 
 import os
-import sys
 import pytest
 
 from click.testing import CliRunner
 
 from dask_ec2.cli.main import cli
 
-
-@pytest.yield_fixture(scope="module")
-def driver():
-    from dask_ec2.ec2 import EC2
-    driver = EC2(region="us-east-1")
-    yield driver
-
-
-remotetest = pytest.mark.skipif('TEST_CLUSTERFILE' not in os.environ,
-                                 reason="Environment variable 'TEST_CLUSTERFILE' is required")
+remotetest = pytest.mark.skipif(
+    'TEST_CLUSTERFILE' not in os.environ, reason="Environment variable 'TEST_CLUSTERFILE' is required")
 
 
 def invoke(*args):
@@ -25,14 +16,7 @@ def invoke(*args):
     args = list(args)
     args.extend(['--file', clusterfile])
     runner = CliRunner()
-    return runner.invoke(cli, args, catch_exceptions=False, input=sys.stdin)
-
-
-@pytest.yield_fixture(scope="module")
-def cluster():
-    from dask_ec2 import Cluster
-    clusterfile = os.environ['TEST_CLUSTERFILE']
-    yield Cluster.from_filepath(clusterfile)
+    return runner.invoke(cli, args, catch_exceptions=False, input=os.devnull)
 
 
 def assert_all_true(salt_output, none_is_ok=False):
